pub struct StyleXTransform<C>where
C: Comments,{
pub comments: C,
props_declaration: Option<Id>,
pub state: StateManager,
}Fields
comments: Cprops_declaration: Option<Id>state: StateManagerImplementations
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_computed_prop_name_impl( &mut self, computed_prop_name: ComputedPropName, ) -> ComputedPropName
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_decl_impl(&mut self, decl: Decl) -> Decl
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_export_decl_impl( &mut self, export_decl: ExportDecl, ) -> ExportDecl
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_export_default_expr_impl( &mut self, export_default_expr: ExportDefaultExpr, ) -> ExportDefaultExpr
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_expr_impl(&mut self, expr: Expr) -> Expr
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_ident_impl(&mut self, ident: Ident) -> Ident
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_import_decl_impl( &mut self, import_decl: ImportDecl, ) -> ImportDecl
fn fill_stylex_create_import( &mut self, source_path: &str, imported_name: String, local_name: &str, import_specifier: &ImportNamedSpecifier, )
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_jsx_attr_or_spreads( &mut self, jsx_attrs: Vec<JSXAttrOrSpread>, ) -> Vec<JSXAttrOrSpread>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_jsx_opening_element_impl( &mut self, jsx_opening_element: JSXOpeningElement, ) -> JSXOpeningElement
Sourcepub(crate) fn transform_sx_in_compiled_jsx(&self, expr: &Expr) -> Option<Expr>
pub(crate) fn transform_sx_in_compiled_jsx(&self, expr: &Expr) -> Option<Expr>
Transform compiled JSX/VDOM calls with an sx prop during the Initializing cycle.
Handles:
- React:
_jsx("div", { sx: expr })/_jsxs("div", { sx: expr }) - React classic:
React.createElement("div", { sx: expr }) - Vue:
_createElementBlock("div", { sx: expr })/_createElementVNode("div", { sx: expr })
Transforms to: fn("div", { ...stylex.props(expr), ... })
Sourcepub(crate) fn transform_sx_in_solid_set_attribute(
&self,
expr: &Expr,
) -> Option<Expr>
pub(crate) fn transform_sx_in_solid_set_attribute( &self, expr: &Expr, ) -> Option<Expr>
Transform Solid.js compiled sx attribute during the Initializing cycle.
Solid.js compiles <div sx={styles.main}> to:
_$setAttribute(_el$, "sx", styles.main)
We transform it to:
_$spread(_el$, _$mergeProps(() => stylex.props(styles.main)), false, true)
Sourcefn get_stylex_ident_name(&self) -> Option<String>
fn get_stylex_ident_name(&self) -> Option<String>
Get the stylex ident name from the import paths. Returns the first stylex import name from the import paths.
Sourcefn get_props_ident_name(&self) -> Option<String>
fn get_props_ident_name(&self) -> Option<String>
Get the props ident name from the import paths. Returns the first props import name from the import paths.
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_member_expr_impl( &mut self, member_expression: MemberExpr, ) -> MemberExpr
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_member_prop_impl( &mut self, member_prop: MemberProp, ) -> MemberProp
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_module_impl(&mut self, module: Module) -> Module
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_module_items( &mut self, module_items: Vec<ModuleItem>, ) -> Vec<ModuleItem>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_named_export_impl( &mut self, named_export: NamedExport, ) -> NamedExport
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_prop_name_impl(&mut self, prop_name: PropName) -> PropName
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_stmt_impl(&mut self, stmt: Stmt) -> Stmt
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_stmts_impl(&mut self, stmts: Vec<Stmt>) -> Vec<Stmt>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_var_declarator_impl( &mut self, var_declarator: VarDeclarator, ) -> VarDeclarator
fn retain_object_props( &self, object: &mut ObjectLit, namespace_to_keep: Vec<Atom>, var_name: &VarDeclarator, ) -> Vec<PropOrSpread>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn fold_var_declarators_impl( &mut self, var_declarators: Vec<VarDeclarator>, ) -> Vec<VarDeclarator>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_default_marker_call( &mut self, call: &CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_define_marker_call( &mut self, call: &CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_attrs_call( &mut self, call: &mut CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_call( &mut self, call: &mut CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_fns( &mut self, call_expr: &mut CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_create( &mut self, call: &CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_create_theme_call( &mut self, call: &CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_define_consts( &mut self, call: &CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_define_vars( &mut self, call: &CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_keyframes_call( &mut self, var_decl: &VarDeclarator, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_position_try_call( &mut self, var_decl: &VarDeclarator, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_props_call( &mut self, call: &mut CallExpr, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub(crate) fn transform_stylex_view_transition_class_call( &mut self, var_decl: &VarDeclarator, ) -> Option<Expr>
Sourceimpl<C> StyleXTransform<C>where
C: Comments,
impl<C> StyleXTransform<C>where
C: Comments,
pub fn new( comments: C, plugin_pass: PluginPass, config: &mut StyleXOptionsParams, ) -> Self
pub fn new_test_force_runtime_injection( comments: C, plugin_pass: PluginPass, config: Option<&mut StyleXOptionsParams>, ) -> Self
pub fn new_test_force_runtime_injection_with_pass( comments: C, plugin_pass: PluginPass, config: Option<&mut StyleXOptionsParams>, ) -> impl Pass + use<C>
pub fn new_test( comments: C, plugin_pass: PluginPass, config: Option<&mut StyleXOptionsParams>, ) -> Self
pub fn new_test_with_pass( comments: C, plugin_pass: PluginPass, config: Option<&mut StyleXOptionsParams>, ) -> impl Pass + use<C>
fn is_stylex_import(&self, ident_sym: &str) -> bool
pub(crate) fn process_declaration( &mut self, call_expr: &mut CallExpr, ) -> Option<(Id, String)>
pub(crate) fn transform_call_expression( &mut self, expr: &mut Expr, ) -> Option<Expr>
pub(crate) fn get_call_var_name( &mut self, call: &CallExpr, ) -> (Option<String>, Option<VarDeclarator>)